@@ -701,7 +701,7 @@ program_list_selection_changed (GtkTreeSelection  *selection,
 {
 	GtkTreeModel     *model;
 	GtkTreeIter       iter;
-	const char       *temp;
+	char             *temp;
 	char             *path, *stripped;
 	GKeyFile         *keyfile;
 		
@@ -737,10 +737,12 @@ program_list_selection_changed (GtkTreeSelection  *selection,
 					      GNOME_DESKTOP_ITEM_URL, NULL);
 		gtk_entry_set_text (GTK_ENTRY (dialog->details->entry), sure_string (temp));
 	}
+	g_free (temp);
 
 	temp = g_key_file_get_locale_string (keyfile, DESKTOP_ENTRY_GROUP,
 					     GNOME_DESKTOP_ITEM_COMMENT, NULL, NULL);
 	gtk_label_set_text (GTK_LABEL (dialog->details->desc_label), sure_string (temp));
+	g_free (temp);
 	gtk_widget_set_sensitive (dialog->details->button, TRUE);
 
 	g_free (dialog->details->desktop_file);
